@@ -16,7 +16,7 @@ use vars qw($VERSION $AUTOLOAD @ISA $AUTO_ADD);
 
 require 5.008;
 
-$VERSION = '1.55';
+$VERSION = '1.57';
 
 $AUTO_ADD = 0;
 
@@ -1267,6 +1267,9 @@ sub _get_parser {
                 # Detach the parser to avoid reference loops.
                 $self->_parser(undef);
             },
+            ExternEnt => sub {
+                return '';
+            },
         }
     );
 }
@@ -2073,7 +2076,7 @@ modify it under the same terms as Perl itself.
  Aaron Straup Cope <asc@vineyard.net>
  Ian Davis <iand@internetalchemy.org>
  rayg@varchars.com
- Shlomi Fish <shlomif@iglu.org.il>
+ Shlomi Fish <shlomif@cpan.org>
 
 =head1 SEE ALSO
 
